==========
Viewpoints
==========

* [17.05] `李德毅：知识工程才是人工智能时代最有意义的课题之一，我乐此不疲 <http://www.leiphone.com/news/201705/NajCp546MOpmKa3R.html>`_
* [16.10] `CNCC 2016｜清华大学张钹院士起底： 后深度学习时代的人工智能 <http://www.leiphone.com/news/201610/my3RisHxpQ0hjvz7.html>`_
* [16.10] `CCL 2016｜ 中科院张钹院士：后深度学习时代的计算语言学 <http://www.leiphone.com/news/201610/Lp2M76VrBubDMB5h.html>`_
